California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 1A - 2000. SCA 11 (RESOLUTION CHAPTER 142, 1999). BURTON. GAMBLING. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991685 | CALIFORNIANS FOR YES ON PROPOSITION 1A, FOR INDIAN SELF-RELIANCE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991680 | CALIFORNIANS FOR YES ON 1A | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991681 | CITIZENS FOR PROPOSITION 1A | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991682 | CALIFORNIA TRIBES FOR PROPOSITION 1A | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991683 | CALIFORNIA TRIBES FOR YES ON 1A | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991684 | CALIFORNIANS FOR INDIAN SELF-RELIANCE FOR PROPOSITION 1A | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991686 | CALIFORNIANS FOR INDIAN SELF-RELIANCE, THE YES ON 1A COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991690 | UNITED TRIBES FOR PROPOSITION 1A | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991691 | NATIVE AMERICANS FOR PROPOSITION 1A | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991692 | COMMITTEE OF CALIFORNIA CITIZENS WHO ASK YOU TO VOTE YES ON 1A | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991693 | YES ON 1A | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991694 | CALIFORNIANS FOR PROPOSITION 1A | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991695 | CALIFORNIA'S YES ON 1A COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991696 | YES ON 1A COMMITTEE, THE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991825 | STOP 1A - NO CASINOS COMMITTEE AGAINST PROPOSITION 1A | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
992094 | YES ON 1A, CALIFORNIANS FOR INDIAN SELF-RELIANCE SPONSORED BY CALIFORNIA INDIAN TRIBES | SUPPORT